/*
 atget.h, by R. Abramson, 74676,3345, 1/24/91
 header file for 'atget', a dBASE-style screen editing module for TC++
 Copyright (c) 1991 R. Abramson.  Licensed without fee for
 non-pecuniary use.

 Use with compiled module atget.obj

 Screen coordinates originate at (1, 1) (upper left) and are in the order
 (row, col), that is, (y, x).

 Example of use:

	void test() {
		char a_string1[21]; // test strings...
		char a_string2[31]; // (you can define up to 25 strings)
		int result;

		gt.gc = 0;  // initializes atget module (extern struct)
		beep_on = 0; // optional, silent mode (extern int)

		strcpy ( a_string1, "This is" ); // put incoming data
		strcpy ( a_string2, "a test." ); // into the strings
		rpad ( a_string1, 20 ); // pad to end with spaces
		rpad ( a_string2, 30 );

		atsay( 1, 1, "Edit this string ==> " ); // put up prompt at coords
		atget( 1,22, a_string1 ); // edit and 'get' string at coords
		atsay( 2, 1, "and this one ..." ); // repeat for next one, etc. ...
		atget( 2,22, a_string2 );
		// repeat for all strings in the edit screen

		result = readgets(); // read and commit data from the open 'gets'
		// strings will be changed as the user edited them
		// result indicates how the operation ended.  'Esc' is 4
*/
//------------------------------------------------------------------------------

static char notice[] = "ATGET Edit Module, copyright (c) 1991 R. Abramson.";

// structure to accommodate up to 25 data entry strings
typedef struct {
	int gc; /* the 'get-count' */
	struct {
		int x;
		int y;
		char *st;
	} ge[24]; /* each 'get-entry' is two coords and a string */
} getrec;

extern getrec gt;
extern int beep_on;

// function prototypes...

// principal functions...
void atsay( int, int, char* ); // output string at coords (y,x)
void atget( int, int, char* );  // edit and get string at coords (y,x)
int readgets( void ); // process all open atgets

// utility functions...
void rtrim( char* ); // trim trailing n\blanks from string
void ltrim( char* ); // trim leading blanks from string
void rpad(  char* , int ); // right-pad string w/ blanks to specified width
void lpad(  char* , int ); // same - from the left
void cls( void );   // clear screen

// internal, supporting functions...
int anti( int );	// reverses sense of a boolean argument
void beep( void );	// simple bell
void pushcursor( void ); // save cursor
void popcursor( void );  // restore cursor
void rvideo( void ); // 'reverse' video
void nvideo( void ); // 'norm' video
void showinsertmode( int ); // display status of insert key
char *strdelete(  char* , int, int ); // delete x chars starting at pos y
void processfk( unsigned ); // internal function for processing f keys
int editline( int, int,  char*  ); // internal function for keystrokes
void gotoyx( int, int ); // reverse of gotoxy
